==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/authorization/entity/MapPolicyEntityDelegate.java <==
package org.keycloak.models.map.authorization.entity;
public class MapPolicyEntityDelegate implements org.keycloak.models.map.authorization.entity.MapPolicyEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapPolicyEntity> delegateProvider;
    public MapPolicyEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapPolicyEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ID, id).setId(id);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.NAME, name).setName(name);
    }
    @Override public String getDescription() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DESCRIPTION).getDescription();
    }
    @Override public void setDescription(String description) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DESCRIPTION, description).setDescription(description);
    }
    @Override public String getType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.TYPE).getType();
    }
    @Override public void setType(String type) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.TYPE, type).setType(type);
    }
    @Override public org.keycloak.representations.idm.authorization.DecisionStrategy getDecisionStrategy() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DECISION_STRATEGY).getDecisionStrategy();
    }
    @Override public void setDecisionStrategy(org.keycloak.representations.idm.authorization.DecisionStrategy decisionStrategy) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DECISION_STRATEGY, decisionStrategy).setDecisionStrategy(decisionStrategy);
    }
    @Override public org.keycloak.representations.idm.authorization.Logic getLogic() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.LOGIC).getLogic();
    }
    @Override public void setLogic(org.keycloak.representations.idm.authorization.Logic logic) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.LOGIC, logic).setLogic(logic);
    }
    @Override public java.util.Map<String,String> getConfigs() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS).getConfigs();
    }
    @Override public void setConfigs(java.util.Map<String,String> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, config).setConfigs(config);
    }
    @Override public String getConfig(String name) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, name).getConfig(name);
    }
    @Override public void setConfig(String name, String value) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, name, value).setConfig(name, value);
    }
    @Override public void removeConfig(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, name).removeConfig(name);
    }
    @Override public String getResourceServerId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_SERVER_ID).getResourceServerId();
    }
    @Override public void setResourceServerId(String resourceServerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_SERVER_ID, resourceServerId).setResourceServerId(resourceServerId);
    }
    @Override public java.util.Set<String> getAssociatedPolicyIds() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS).getAssociatedPolicyIds();
    }
    @Override public void addAssociatedPolicyId(String policyId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS, policyId).addAssociatedPolicyId(policyId);
    }
    @Override public void removeAssociatedPolicyId(String policyId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS, policyId).removeAssociatedPolicyId(policyId);
    }
    @Override public java.util.Set<String> getResourceIds() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS).getResourceIds();
    }
    @Override public void addResourceId(String resourceId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS, resourceId).addResourceId(resourceId);
    }
    @Override public void removeResourceId(String resourceId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS, resourceId).removeResourceId(resourceId);
    }
    @Override public java.util.Set<String> getScopeIds() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS).getScopeIds();
    }
    @Override public void addScopeId(String scopeId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS, scopeId).addScopeId(scopeId);
    }
    @Override public void removeScopeId(String scopeId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS, scopeId).removeScopeId(scopeId);
    }
    @Override public String getOwner() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.OWNER).getOwner();
    }
    @Override public void setOwner(String owner) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.OWNER, owner).setOwner(owner);
    }
}

==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/authorization/entity/MapPolicyEntityDelegate.java <==
package org.keycloak.models.map.authorization.entity;
public class MapPolicyEntityDelegate implements org.keycloak.models.map.authorization.entity.MapPolicyEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapPolicyEntity> delegateProvider;
    public MapPolicyEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapPolicyEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ID, id).setId(id);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.NAME, name).setName(name);
    }
    @Override public String getDescription() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DESCRIPTION).getDescription();
    }
    @Override public void setDescription(String description) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DESCRIPTION, description).setDescription(description);
    }
    @Override public String getType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.TYPE).getType();
    }
    @Override public void setType(String type) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.TYPE, type).setType(type);
    }
    @Override public org.keycloak.representations.idm.authorization.DecisionStrategy getDecisionStrategy() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DECISION_STRATEGY).getDecisionStrategy();
    }
    @Override public void setDecisionStrategy(org.keycloak.representations.idm.authorization.DecisionStrategy decisionStrategy) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.DECISION_STRATEGY, decisionStrategy).setDecisionStrategy(decisionStrategy);
    }
    @Override public org.keycloak.representations.idm.authorization.Logic getLogic() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.LOGIC).getLogic();
    }
    @Override public void setLogic(org.keycloak.representations.idm.authorization.Logic logic) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.LOGIC, logic).setLogic(logic);
    }
    @Override public java.util.Map<String,String> getConfigs() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS).getConfigs();
    }
    @Override public void setConfigs(java.util.Map<String,String> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, config).setConfigs(config);
    }
    @Override public String getConfig(String name) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, name).getConfig(name);
    }
    @Override public void setConfig(String name, String value) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, name, value).setConfig(name, value);
    }
    @Override public void removeConfig(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.CONFIGS, name).removeConfig(name);
    }
    @Override public String getResourceServerId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_SERVER_ID).getResourceServerId();
    }
    @Override public void setResourceServerId(String resourceServerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_SERVER_ID, resourceServerId).setResourceServerId(resourceServerId);
    }
    @Override public java.util.Set<String> getAssociatedPolicyIds() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS).getAssociatedPolicyIds();
    }
    @Override public void addAssociatedPolicyId(String policyId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS, policyId).addAssociatedPolicyId(policyId);
    }
    @Override public void removeAssociatedPolicyId(String policyId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.ASSOCIATED_POLICY_IDS, policyId).removeAssociatedPolicyId(policyId);
    }
    @Override public java.util.Set<String> getResourceIds() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS).getResourceIds();
    }
    @Override public void addResourceId(String resourceId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS, resourceId).addResourceId(resourceId);
    }
    @Override public void removeResourceId(String resourceId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.RESOURCE_IDS, resourceId).removeResourceId(resourceId);
    }
    @Override public java.util.Set<String> getScopeIds() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS).getScopeIds();
    }
    @Override public void addScopeId(String scopeId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS, scopeId).addScopeId(scopeId);
    }
    @Override public void removeScopeId(String scopeId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.SCOPE_IDS, scopeId).removeScopeId(scopeId);
    }
    @Override public String getOwner() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.OWNER).getOwner();
    }
    @Override public void setOwner(String owner) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapPolicyEntityFields.OWNER, owner).setOwner(owner);
    }
}
